%% Potential Output Model 
clear all
close all
clc

% set countries
countrycode = 'USA';

% set dates
startyear = yy(1990); % filter start date

startest = yy(1990); % estimation start date

endyear = yy(2016); % estimation/filter end date; ie. end date of information provided

endhist = yy(2014); % end of historical data

% set model file
modfile = 'MVF_wp1579.model';

% set initial parameters values
P = struct('lambda',0.25,...
    'beta',0.25,...
    'phi',0.6,...
    'theta',0.1,...
    'std_RES_LGDP_BAR',0.2,...
    'std_RES_G',0.2,...
    'std_RES_Y',0.8,...
    'std_RES_PIE',0.25,...
    'tau1',0.3,...
    'tau2',0.3,...
    'tau3',0.1,...
    'tau4',0.1,...
    'growth_ss',2.44,... % steady state growth rate
    'unr_ss',5.75); % steady state unemployment rate

% set parameter priors for those to be estimated
% (parameter estimates from this prior will overwrite what's specified above)
E.lambda={.25,0.05,0.99,logdist.normal(.25,.1)};
E.beta  ={.25,0.05,3,logdist.normal(.25,.1)};
E.phi   ={.6,0.1,0.99,logdist.normal(.6,.1)};
E.theta ={.1,0.05,0.9,logdist.normal(.1,.1)};

E.std_RES_LGDP_BAR={.2,0.005,3,logdist.normal(.2,.01)};
E.std_RES_G={.2,0.005,3,logdist.normal(.2,.01)};
E.std_RES_Y={.8,0.005,3,logdist.normal(.8,.01)};

E.std_RES_PIE={.25,0.005,3,logdist.normal(.25,.2)};

E.std_RES_UNR_GAP={.5,0.005,3,logdist.normal(.5,.01)};
E.std_RES_UNR_BAR={.1,0.005,3,logdist.normal(.1,.01)};
E.std_RES_G_UNR_BAR={.1,0.005,3,logdist.normal(.1,.01)};

E.tau1  ={.3,0.05,0.99,logdist.normal(.3,.1)};
E.tau2  ={.3,0.05,0.99,logdist.normal(.3,.1)};
E.tau3  ={.1,0.05,0.99,logdist.normal(.1,.01)};
E.tau4  ={.1,0.05,0.99,logdist.normal(.1,.01)};


% set data file
datafile = ['data',filesep,'US_data.csv']; % including historical data, forecasts, and judgments (if any)

% impose judgment (for potential, otuput gap and NAIRU, at the end of
% sample)
% 1: on; 0: off
judgment = 1;



